@@ -11,7 +11,7 @@ use List::MoreUtils qw(uniq);
 use Rose::HTML::Util();
 use Rose::HTML::Object::Message::Localizer;
 
-our $VERSION = '0.616';
+our $VERSION = '0.618';
 
 our $Debug = undef;
 
@@ -1872,7 +1872,7 @@ L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Rose-HTML-Objects>
 
 There's also a wiki and other resources linked from the Rose project home page:
 
-L<http://rose.googlecode.com>
+L<http://rosecode.org>
 
 =head1 AUTHOR
 
